function [dat]=ampreg2_spl(dat,std1,std2)
% [dat]=ampreg1(dat,std1,std2)
% fit O and C data to log(A)
% requires statistics toolbox: regress.m
% v1 MNE 5/22/14

% need the number of samples+stds first:
%dat.nrc=size(dat.numc,1); already set in check1.m 

% check if there is already a spline fit correction:
if isfield(dat,'splc'),
    % create correction basis for amplitude fit
    % two columns for C and O
    dat.cria=dat.splc;
    % initialize dat.ampc:
    dat.ampc=NaN(size(dat.cria,1),4);
% if not, use the raw data as basis
else
    % two columns for C and O (two copies, to allow for possibility that
    % we've run pwreg1 first!
    dat.cria=[dat.numc(:,6:7) dat.numc(:,6:7)];
    % initialize dat.ampc:
    dat.ampc=NaN(size(dat.cria,1),4);
end
% in either case, the basis for amplitude correction is
dat.amp=dat.numc(:,4); %dat.numc(:,5) is sample weight; kjs changed to dat.numc(:,4)
% which is amplitude

% initialize matrices for std1 and std2 piecewise regression fits
cc=NaN(size(dat.cria,1),4); % for j=1 std, then j=2 std
%k=0;
k=1;
for j=1:2 % 2 stds
    for i=1:2 % 2 isotopes
        sname=['dat.std' num2str(j)]; % std name
        jname=['dat.pos' num2str(j)]; % index position for standard j
        %[b,bint,r,rint,stats] = regress(eval(['dat.cria(' jname ',i)']),[ones(eval(['length(' jname ')']),1) log(eval(['dat.amp(' jname ')']))]); 
        [b,bint,r,rint,stats] = regress(eval(['dat.cria(' jname ',k)']),[ones(eval(['length(' jname ')']),1) log(eval(['dat.amp(' jname ')']))]); 
        % get predicted values, but only if regression fit is good:
        if stats(3)>0.1, % require p-value of amplitude regression to be less than pcrit,
            if i==1,
                %cc1=cc1+1;
                %eval(['c1(:,j)=dat.numc(:,i+8)-(b(2,:)*log(dat.numc(:,5))+b(1,:))+mean(dat.numc(' jname ',i+8));']);%correct to dat.stdj C mean value
                disp(['amplitude correction for c13 for ' num2str(sname) ' not significant at p<=0.1: (r^2,p) = ' num2str(stats([1 3])) ])
                % keep the regression anyway:
                rname=['b13_' num2str(j)]; % regression name
                % write the regression coefficients into dat.rname:
                eval(['dat.' rname '=b;'])
                eval(['dat.' rname 'stats=stats;'])
                %k=k+1; % increment k
                eval(['cc(:,' num2str(k) ')=dat.cria(:,' num2str(k) ')-mean(dat.cria(' jname ',' num2str(k) '));']); % anomaly wrt standard j
                k=k+1;
            elseif i==2,
                %cc2=cc2+1;
                %eval(['c2(:,j)=dat.numc(:,i+8)-(b(2,:)*log(dat.numc(:,5))+b(1,:))+mean(dat.numc(' jname ',i+8));']);%correct to dat.stdj O mean value
                disp(['amplitude correction for o18 for ' num2str(sname) ' not significant at p<=0.1: (r^2,p) = ' num2str(stats([1 3])) ])
                % keep the regression anyway:
                rname=['b18_' num2str(j)]; % regression name
                % write the regression coefficients into dat.rname:
                eval(['dat.' rname '=b;'])
                eval(['dat.' rname 'stats=stats;'])
                %k=k+1; % increment k
                eval(['cc(:,' num2str(k) ')=dat.cria(:,' num2str(k) ')-mean(dat.cria(' jname ',' num2str(k) '));']); % anomaly wrt standard j
                k=k+1; % increment k
            end
        elseif stats(3)<=0.1, % require p-value of amplitude regression to be less than pcrit,
            if i==1,% amplitude correct the c13 data:
                
                %k=k+1;
                eval(['cc(:,k)=dat.cria(:,i)-(b(2,:)*log(dat.amp)+b(1,:));']); %+dat.std' num2str(j) 'c;']);%correct to dat.stdj C mean value
                % regression for carbon:
                rname=['b13_' num2str(j)]; % regression name
                % write the regression coefficients into dat.rname:
                eval(['dat.' rname '=b;'])
                eval(['dat.' rname 'stats=stats;'])
                disp(['amplitude correction for c13 for ' num2str(sname) ' is  significant at p<=0.1: (r^2,p) = ' num2str(stats([1 3])) ])
                k=k+1;
            elseif i==2,
                %k=k+1;
                eval(['cc(:,k)=dat.cria(:,i)-(b(2,:)*log(dat.amp)+b(1,:));']); %+dat.std' num2str(j) 'o;']);%correct to dat.stdj O mean value
                % regression for oxygen:
                rname=['b18_' num2str(j)]; % regression name
                % write the regression coefficients into dat.rname:
                eval(['dat.' rname '=b;'])
                eval(['dat.' rname 'stats=stats;'])
                disp(['amplitude correction for o18 for ' num2str(sname) ' is  significant at p<=0.1: (r^2,p) = ' num2str(stats([1 3])) ])
                k=k+1;
            end
        end
             
        
    end
end

% average the piecewise regressions across stds
% do we want to weight the corrections toward one spline or the other?
%dat.ampc(:,1)=nanmean(cc(:,[1 3]),2);
%dat.ampc(:,2)=nanmean(cc(:,[2 4]),2);

% keep all corrections
dat.ampc=cc;

% write out mean and std of corrected values
[mean(dat.ampc(dat.pos1,1))  mean(dat.ampc(dat.pos1,2)) mean(dat.ampc(dat.pos2,3))  mean(dat.ampc(dat.pos2,4));
    std(dat.ampc(dat.pos1,1))  std(dat.ampc(dat.pos1,2)) std(dat.ampc(dat.pos2,3))  std(dat.ampc(dat.pos2,4))]

% average the amplitude corrections across standards (if any):
%if cc1~=0,
%    dat.ampc(:,1)=nanmean(c1,2);
%elseif cc1==0,
%    dat.ampc(:,1)=dat.cria(:,1);
%end
%if cc2~=0,
%    dat.ampc(:,2)=nanmean(c2,2);
%elseif cc2==0,
%    dat.ampc(:,2)=dat.cria(:,2);
%end

% record the time of completion for determining which correction (amp, spl)
% was performed first (see help clock):
pause(1); % make sure that the time is distinguisable from pwreg1 clock time
dat.ampc_time=clock;
return
