function[dat]=mkval1(input)
% ingests output dat structure from running the modularized correction
% algorithm
% outputs:
% dat.val_[std]: 1x4 vector with c13_mean, o18_mean, c13_std, o18_std
% std = nbs, lsvec, jtb, mcc, eacarb, iaea (carbonates)
% std = 

% evaluate the validation standards from 
% multiflow: 10042012_REP_100ug_validation,
%            03142013_BTB_100ug_Validation_corr, 
% costech: 06052014_KJS_100ug_cellulose_validation_experiment_corr, 
%          07252014_KJS_100ug_cellulose_validation_experiment_corr
% batchfile using modularized correction scripts:
% based on run_fanalyze_stds4_100ug.m (MNE 2/2013)

%load 10042012_REP_100ug_validation_corr.mat
load([input])

% find the validation data
% case: CO2 analyte
if strcmp(dat.analyte,'CO2'),
    dat.valdat=zeros(length(dat.txtc),3); % index c13c o18c
    dat.valtxt=cell(length(dat.txtc),1); % names
    % first the carbonate possibilities
    for i=1:length(dat.txtc)
        if ~isempty(cell2mat(strfind(dat.txtc(i,2),'nbs'))) | ~isempty(cell2mat(strfind(dat.txtc(i,2),'_N_')))
            dat.valdat(i,1)=1;
            dat.valdat(i,2:3)=dat.crf(i,:);
            %dat.valtxt(i)=cell2mat(dat.txtc(i,2));
            dat.valtxt(i)=dat.txtc(i,2);
        elseif ~isempty(cell2mat(strfind(dat.txtc(i,2),'lsvec'))) | ~isempty(cell2mat(strfind(dat.txtc(i,2),'_L_')))
            dat.valdat(i,1)=2;
            dat.valdat(i,2:3)=dat.crf(i,:);
            %dat.valtxt(i)=cell2mat(dat.txtc(i,2));
            dat.valtxt(i)=dat.txtc(i,2);
        elseif ~isempty(cell2mat(strfind(dat.txtc(i,2),'jtb'))) | ~isempty(cell2mat(strfind(dat.txtc(i,2),'_J_')))
            dat.valdat(i,1)=3;
            dat.valdat(i,2:3)=dat.crf(i,:);
            %dat.valtxt(i)=cell2mat(dat.txtc(i,2));
            dat.valtxt(i)=dat.txtc(i,2);
        elseif  ~isempty(cell2mat(strfind(dat.txtc(i,2),'mcc'))) | ~isempty(cell2mat(strfind(dat.txtc(i,2),'MCC'))) | ~isempty(cell2mat(strfind(dat.txtc(i,2),'_M_')))
            dat.valdat(i,1)=4;
            dat.valdat(i,2:3)=dat.crf(i,:);
            %dat.valtxt(i)=cell2mat(dat.txtc(i,2));
            dat.valtxt(i)=dat.txtc(i,2);
        elseif  ~isempty(cell2mat(strfind(dat.txtc(i,2),'eacarb'))) | ~isempty(cell2mat(strfind(dat.txt(i,2),'_E_')))
            dat.valdat(i,1)=5;
            dat.valdat(i,2:3)=dat.crf(i,:);
            %dat.valtxt(i)=cell2mat(dat.txtc(i,2));
            dat.valtxt(i)=dat.txtc(i,2);
        elseif  ~isempty(cell2mat(strfind(dat.txtc(i,2),'iaea'))) | ~isempty(cell2mat(strfind(dat.txtc(i,2),'_I_')))
            dat.valdat(i,1)=6;
            dat.valdat(i,2:3)=dat.crf(i,:);
            dat.valtxt(i)=dat.txtc(i,2);
        end
    end

    % calculate validation accuracies and precisions
    for i=1:6
        j=find(dat.valdat(:,1)==i);
        if i==1 && ~isempty(j),
            dat.val_nbs=[mean(dat.valdat(j,[2 3])) std(dat.valdat(j,[2 3]))];
        elseif i==2 && ~isempty(j),
            dat.val_lsvec=[mean(dat.valdat(j,[2 3])) std(dat.valdat(j,[2 3]))]; 
        elseif i==3 && ~isempty(j),
            dat.val_jtb=[mean(dat.valdat(j,[2 3])) std(dat.valdat(j,[2 3]))];
        elseif i==4 && ~isempty(j),
            dat.val_mcc=[mean(dat.valdat(j,[2 3])) std(dat.valdat(j,[2 3]))];
        elseif i==5 && ~isempty(j),
            dat.val_eacarb=[mean(dat.valdat(j,[2 3])) std(dat.valdat(j,[2 3]))];
        elseif i==6 && ~isempty(j),
            dat.val_iaea=[mean(dat.valdat(j,[2 3])) std(dat.valdat(j,[2 3]))];
        end
    end
end

% case: CO analyte
% (e.g. load 07252014_KJS_100ug_cellulose_validation_experiment_corr)
% 1=SAC
% 2=AKC
% 3=AWS
% 4=MASA
% 5=H1
% 6=L6
% 7=Switsur
% 8=IAEA-CH3 (Boettger)
if strcmp(dat.analyte,'CO'),
    dat.valdat=zeros(length(dat.txtc),3); % index c13c o18c
    dat.valtxt=cell(length(dat.txtc),1); % names
    % first the carbonate possibilities
    for i=1:length(dat.txtc)
        if ~isempty(cell2mat(strfind(dat.txtc(i,2),'sac')))
            dat.valdat(i,1)=1;
            dat.valdat(i,2:3)=dat.crf(i,:);
            dat.valtxt(i)=dat.txtc(i,2);
        elseif ~isempty(cell2mat(strfind(dat.txtc(i,2),'akc')))
            dat.valdat(i,1)=2;
            dat.valdat(i,2:3)=dat.crf(i,:);
            dat.valtxt(i)=dat.txtc(i,2);
        elseif ~isempty(cell2mat(strfind(dat.txtc(i,2),'AWS')))
            dat.valdat(i,1)=3;
            dat.valdat(i,2:3)=dat.crf(i,:);
            dat.valtxt(i)=dat.txtc(i,2);
        elseif  ~isempty(cell2mat(strfind(dat.txtc(i,2),'masa')))
            dat.valdat(i,1)=4;
            dat.valdat(i,2:3)=dat.crf(i,:);
            dat.valtxt(i)=dat.txtc(i,2);
        elseif  ~isempty(cell2mat(strfind(dat.txtc(i,2),'H1')))
            dat.valdat(i,1)=5;
            dat.valdat(i,2:3)=dat.crf(i,:);
            dat.valtxt(i)=dat.txtc(i,2);
        elseif  ~isempty(cell2mat(strfind(dat.txtc(i,2),'L6')))
            dat.valdat(i,1)=6;
            dat.valdat(i,2:3)=dat.crf(i,:);
            dat.valtxt(i)=dat.txtc(i,2);
        elseif  ~isempty(cell2mat(strfind(dat.txtc(i,2),'Switsur')))
            dat.valdat(i,1)=7;
            dat.valdat(i,2:3)=dat.crf(i,:);
            dat.valtxt(i)=dat.txtc(i,2);
        elseif  ~isempty(cell2mat(strfind(dat.txtc(i,2),'IAEA-CH6')))
            dat.valdat(i,1)=8;
            dat.valdat(i,2:3)=dat.crf(i,:);
            dat.valtxt(i)=dat.txtc(i,2);
        end
    end

    % calculate validation accuracies and precisions
    for i=1:8
        j=find(dat.valdat(:,1)==i);
        if i==1 && ~isempty(j),
            dat.val_sac=[mean(dat.valdat(j,[2 3])) std(dat.valdat(j,[2 3]))];
        elseif i==2 && ~isempty(j),
            dat.val_akc=[mean(dat.valdat(j,[2 3])) std(dat.valdat(j,[2 3]))]; 
        elseif i==3 && ~isempty(j),
            dat.val_aws=[mean(dat.valdat(j,[2 3])) std(dat.valdat(j,[2 3]))];
        elseif i==4 && ~isempty(j),
            dat.val_masa=[mean(dat.valdat(j,[2 3])) std(dat.valdat(j,[2 3]))];
        elseif i==5 && ~isempty(j),
            dat.val_h1=[mean(dat.valdat(j,[2 3])) std(dat.valdat(j,[2 3]))];
        elseif i==6 && ~isempty(j),
            dat.val_l6=[mean(dat.valdat(j,[2 3])) std(dat.valdat(j,[2 3]))];
        elseif i==7 && ~isempty(j),
            dat.val_switsur=[mean(dat.valdat(j,[2 3])) std(dat.valdat(j,[2 3]))];
        elseif i==8 && ~isempty(j),
            dat.val_iaea_ch3=[mean(dat.valdat(j,[2 3])) std(dat.valdat(j,[2 3]))];
        end
    end
end

return





if 0,



% results table:            
% c13k c13ks o18k o18ks c13c c13cs o18c o18cs N c13v c13vs o18v o18vs N
dat.valtable=[[dat.stddat_CO2(2,:) dat.tpcqc(15) dat.std2_sd(15) dat.std2_mean(16) dat.std2_sd(16) length(dat.stdinclude2) dat.val_lsvec([1 3 2 4]) length(find(dat.valdat(:,1)==2))];
    [dat.stddat_CO2(3,:) [NaN NaN NaN NaN NaN ] dat.val_jtb([1 3 2 4]) length(find(dat.valdat(:,1)==3))];
    [dat.stddat_CO2(5,:) [NaN NaN NaN NaN NaN] dat.val_eacarb([1 3 2 4]) length(find(dat.valdat(:,1)==5))];
    [dat.stddat_CO2(6,:) dat.std1_mean(15) dat.std1_sd(15) dat.std1_mean(16) dat.std1_sd(16) length(dat.stdinclude1) dat.val_iaea([1 3 2 4]) length(find(dat.valdat(:,1)==6))]]

%dat.valtable=[[dat.stddat_CO2(2,:) dat.std2_mean(15) dat.std2_sd(15) dat.std2_mean(16) dat.std2_sd(16) length(dat.stdinclude2) dat.val_lsvec([1 3 2 4]) length(find(dat.valdat(:,1)==2))];
%    [dat.stddat_CO2(3,:) [NaN NaN NaN NaN NaN ] dat.val_jtb([1 3 2 4]) length(find(dat.valdat(:,1)==3))];
%    [dat.stddat_CO2(5,:) [NaN NaN NaN NaN NaN] dat.val_eacarb([1 3 2 4]) length(find(dat.valdat(:,1)==5))];
%    [dat.stddat_CO2(6,:) dat.std1_mean(15) dat.std1_sd(15) dat.std1_mean(16) dat.std1_sd(16) length(dat.stdinclude1) dat.val_iaea([1 3 2 4]) length(find(dat.valdat(:,1)==6))]]

% t-tests for differences in means

% IAEA validation and calibration: including that one outlier (#7)
i=find(dat.valdat(:,1)==6);
[h6c,p6c,ci6c,stats6c]=ttest(dat.corr(dat.stdinclude1,19),dat.valdat(i,20)) % Reject Ho
[h6o,p6o,ci6o,stats6o]=ttest(dat.corr(dat.stdinclude1,20),dat.valdat(i,21)) % Accept Ho
% LSVEC validation and calibration
i=find(dat.valdat(:,1)==2);
[h2c,p2c,ci2c,stats2c]=ttest(dat.corr(dat.stdinclude2,19),dat.valdat(i,20)) %  Accept Ho
[h2o,p2o,ci2o,stats2o]=ttest(dat.corr(dat.stdinclude2,20),dat.valdat(i,21)) %  Accept Ho
% JTB validation and calibration
i=find(dat.valdat(:,1)==3);
[h2c,p2c,ci2c,stats2c]=ttest(dat.valdat(i,20),dat.stddat_CO2(3,1)) %  Reject Ho
[h2o,p2o,ci2o,stats2o]=ttest(dat.valdat(i,21),dat.stddat_CO2(3,3)) %  Reject Ho
% EACARB validation and calibration
i=find(dat.valdat(:,1)==5);
[h2c,p2c,ci2c,stats2c]=ttest(dat.valdat(i,20),dat.stddat_CO2(5,1)) %  Reject Ho
[h2o,p2o,ci2o,stats2o]=ttest(dat.valdat(i,21),dat.stddat_CO2(5,3)) %  Reject Ho

save run_fanalyze_stds4_100ug_work

% Note: leaving off the one IAEA flier: 
% std(dat.valdat(i([1:6 8:10]),20:21))
% ans =
%
%    0.0540    0.0726
end
