function [dat]=splreg1(dat,std1,std2,tol)
% [dat]=ampreg1(dat,std1,std2)
% fit O and C data to stiff spline through sequential stds
% requires statistics toolbox: regress.m
% v1 MNE 5/27/14; modified 1/14/15 KJS
% replaced dat.cri with dat.cris so that data would be saved in dat and
% could be accessed in plotting function

% need the number of samples+stds first:
%dat.nr=size(dat.numc,1);

% check if there is already a amplitude correction:
if isfield(dat,'ampc'),
    % create correction basis for spline fit
    % two columns for C and O
    dat.cris=dat.ampc;
    % initialize dat.splc:
    dat.splc=NaN(size(dat.cris,1),4);
% if not, use the raw data as basis
else
    % two columns for C and O
    dat.cris=[dat.numc(:,6:7) dat.numc(:,6:7)];
    % initialize dat.splc:
    dat.splc=NaN(size(dat.cris, 1),4);
end

% vectors to hold corrections
c1=NaN(size(dat.cris)); % c1 holds up to two corrections for c13
c2=c1; % c2 holds up to two corrections for o18
% count number of corrections made per isotope
cc1=0; % for carbon
cc2=0; % for oxygen

% hardcode tol for now
%tol=4; %piecewise linear interpolation

% 1. Find standard nodes

% identify the standards in each node (there should be 4 nodes for a
%  standard 99 position run)
% make a vector with all the standard positions  
dat.stdpos=sort([dat.pos1; dat.pos2]);

% initiate column identifier
k=1;
% group standards that are offset by 1, indicating that they are in the
% same node
for i=1:length(dat.stdpos);
    if i==1
        mnode(i,k)=dat.stdpos(i);
    elseif dat.stdpos(i)-dat.stdpos(i-1)<=1
        mnode(i,k)=dat.stdpos(i);
    else
        k=k+1;
        mnode(i,k)=dat.stdpos(i);
    end
end

% header: mean position, mean 13c, mean 18o
for i=1:size(mnode,2)
  dat.include1n(i,1)=[mean(intersect(dat.pos1,mnode(:,i)))]'; 
  dat.include1n(i,2)=mean(dat.cris(intersect(dat.pos1,mnode(:,i)),1));
  dat.include1n(i,3)=mean(dat.cris(intersect(dat.pos1,mnode(:,i)),2));
  dat.include2n(i,1)=[mean(intersect(dat.pos2,mnode(:,i)))]';
  dat.include2n(i,2)=mean(dat.cris(intersect(dat.pos2,mnode(:,i)),3)); 
  dat.include2n(i,3)=mean(dat.cris(intersect(dat.pos2,mnode(:,i)),4));
end
%end % end zero loop

% remove missing values from dat.include1n and dat.include2n (happens when
% SAC and MASA are used as correcting standards because AWS is between
% them; if SAC and AWS are selected then NAN will not appear)
i=find(~isnan(dat.include1n(:,1)));
dat.include1n2=dat.include1n(i,:);
j=find(~isnan(dat.include2n(:,1)));
dat.include2n2=dat.include2n(j,:);

% create matrix that has both standards and their average positions
dat.includen=[dat.include1n2 dat.include2n2];

% initiate matrices for std1 and std2 spline fits
cc=NaN(size(dat.cris,1),4); % for j=1 std, then j=2 std
% initiate column identifier for node positions
k=0;
b=0;dat.splr=NaN(1,4); % save the spline correction range
for j=1:2 % 2 stds
    for i=1:2 % 2 isotopes
        sname=['dat.std' num2str(j)]; % std name
        %jname=['dat.pos' num2str(j)]; % index position for standard j
        jname=['dat.include' num2str(j) 'n2']; % index position for standard j
        
        % 2. interpolate all positions        
        % make the spline correction:
        %eval(['[sp,yi]=spaps(' jname '(:,1),' jname '(:,i+1),ones(size(' jname ',1),1).*tol.*std(' jname '(:,i+1))^2);'])
        eval(['[sp,yi]=spaps(' jname '(:,1),' jname '(:,i+1),tol.*std(' jname '(:,i+1))^2);'])
        %eval(['[sp,yi]=spaps(' jname '(:,1),' jname '(:,i+1),length(' jname ').*tol.*std(' jname '(:,i+1))^2);'])
        b=b+1;eval(['dat.splf' num2str(b) '=yi;']);
        pp=sp2pp(sp); % convert spline from B-form to ppform
        eval(['yi2=ppval(pp,' num2str(1) ':' num2str(dat.nrc) ');']); % evaluate piecewise polynomial
        %eval(['yi2=ppval(pp,' num2str(dat.include(1)) ':' num2str(dat.include(length(dat.include))) ');']) % evaluate piecewise polynomial
        dat.splr(b)=range(yi2); % save the range of the spline fit 
        
        % 3. extrapolate
        pp2=fnxtr(pp,1); % extrapolate piecewise polynomial function
        eval(['yi3=ppval(pp2,' num2str(1) ':' num2str(dat.nrc) ');']) % evaluate piecewise polynomial;
        eval(['dat.splfx' num2str(b) '=yi3;']);
        %eval(['dat.yi3' num2str(j) num2str(i) '=ppval(pp2,' num2str(1) ':' num2str(dat.nrc) ');']) % evaluate piecewise polynomial;
        %yi3
        
        % 4. apply correction        
        k=k+1;
        eval(['c1=dat.cris(:,' num2str(k) ')-transpose(yi3);'])
        
        % plot to see if spline is fitting nodes 
        figure(1);
        eval(['subplot(22' num2str(k) ')']); %figure(k);
        eval(['plot(dat.pos' num2str(j) ',dat.cris(dat.pos' num2str(j) ',' num2str(k) '), ''bo'')'])
        lab=sprintf('standard %d isotope %d',j,i);
        title(lab);
        hold on;
        plot(yi3);
        hold off; 
        
        % plot to see anomalies after spline correction is applied
        figure(2);
        eval(['subplot(22' num2str(k) ')']); %figure(k);
        eval(['plot(dat.pos' num2str(j) ', c1(dat.pos' num2str(j) '), ''bo'')'])
        lab=sprintf('standard %d isotope %d',j,i);
        title(lab);
         
        
        % check to see if mean of y is equal to mean of node
        % ymean is not zero because of the effects of the extrapolation
        ymean=nanmean(yi3); eval(['nodalmean=nanmean(' jname '(:,' num2str(i+1) '));'])
        
        % this is relic code: corrected to difference between pwreg
        % correction at standard positions and nodal std values, not
        % correct
        %eval(['c1c=c1+(mean(c1(dat.pos' num2str(j) '))-mean(' jname '(:,i+1)));'])
        
        % remove mean to leave anomalies:
        if i==1,
            eval(['c1c=c1-mean(c1(dat.pos' num2str(j) '));']); %+ dat.std' num2str(j) 'c;'])
        elseif i==2,
            eval(['c1c=c1-mean(c1(dat.pos' num2str(j) '));']); %'))+ dat.std' num2str(j) 'o;'])
        end
        % mean(c1c(dat.pos1)) will differ a bit from mean(dat.include1n2(:,2) b/c of the effect of the extrapolates. Unless we only  
        % plot it and check
        %plot(dat.include1n2(:,1),dat.include1n2(:,2),'o-',dat.numc(dat.pos1,1),c1c(dat.pos1),'rx-',dat.numc(:,1),c1c,'bx')
        
        % write result into cc:
        
        cc(:,k)=c1c; %c13_std1 o18_std1 c13std2 o18std2 
        
    end
end

% write cc into dat.splc, keeping all four corrections (or not)
dat.splc=cc;

% write out mean and std of corrected values
disp(['mean and standard deviation of input and spline-corrected values (c13_1 o18_1 c13_2 o18_2:']) 
[mean(dat.splc(dat.pos1,1))  mean(dat.splc(dat.pos1,2)) mean(dat.splc(dat.pos2,3))  mean(dat.splc(dat.pos2,4));
    std(dat.splc(dat.pos1,1))  std(dat.splc(dat.pos1,2)) std(dat.splc(dat.pos2,3))  std(dat.splc(dat.pos2,4))]
   
disp(['range of spline corrections (c13_1 o18_1 c13_2 o18_2):'])
[dat.splr] 
% record the time of completion for determining which correction (amp, spl)
% was performed first (see help clock):
pause(1); % make sure that the time is distinguisable from ampreg1 clock time
dat.splc_time=clock;
return
