function [dat]=stdrec1(dat,analyte,std1,std2)
% [dat]=stdrec(dat,std1,std2)
% case sensitive: for correcting standards, put the identifiers
% NBS, LSVEC, JTB, MCC, EACARB, IAEA, SAC, AWS, AKC, MASA in the sampleID
% entries so this function can detect them.
% Leave [] for one point corrections
% cases: std1=IAEA; std2=LSVEC
% minimal error checking
% MNE 5/22/14-6/3/14 v1

dat.std1=std1;
dat.std2=std2;
% for now only implemented for 2 point corrections:
% IAEA=LSVEC
% JTB-MCC
% SAC-AKC
% SAC-AWS
% SAC-MASA
% BCB-TJB (carbonate-DIC)
% HLB-HLD (lignins)

% reset dat.analyte (useful if reading organic combustion data):
dat.analyte=analyte;

if strcmp(dat.analyte,'CO2'),
    %carbonate standards: C (1s)  O (1s)
    dat.stddat_CO2=[1.95 0.07 -2.2 0.09; % NBS-19
               -46.6 0.07 -26.7 0.09% LSVEC
                1.78 0.06 -8.71 0.09 % JTB-1
                -36.01 0.06 -21.73 0.12 % MCC-1
                 -36.1 0.08 -21.8 0.10 % EACARB
                 2.492 0.03 -2.4 0.1 % IAEA-CO-1
                 -0.92 0.05 -11.01 0.08 % BCB
                 -18.65 0.09 -20.40 0.10]; % TJB
             
             
% find the std positions 
d=zeros(size(dat.txtc,1),1);
if isempty(dat.std1) && isempty(dat.std2),
    error('no standards identified')
end
% find the std positions: carbonate
    % check for CO2 : how can we write this to be totally general for any
    % two standards?
    % for now, it can be:
    % std1: JTB
    % std2: MCC
    if strcmp(dat.std1,'IAEA'),
        dat.std1c=dat.stddat_CO2(6,1);
        dat.std1o=dat.stddat_CO2(6,3);
        for i=1:size(dat.txtc,1)
            if ~isempty(cell2mat(strfind(dat.txtc(i,2),'IAEA')))
                d(i)=1;
            end
        end
        j=find(d==1);
        dat.std1i=j;
    end
        if strcmp(dat.std1,'JTB'),
        dat.std1c=dat.stddat_CO2(3,1);
        dat.std1o=dat.stddat_CO2(3,3);
        for i=1:size(dat.txtc,1)
            if ~isempty(cell2mat(strfind(dat.txtc(i,2),'JTB')))
                d(i)=1;
            end
        end
        j=find(d==1);
        dat.std1i=j;
    end
    if strcmp(dat.std1,'BCB'),
        dat.std1c=dat.stddat_CO2(7,1);
        dat.std1o=dat.stddat_CO2(7,3);
        for i=1:size(dat.txtc,1)
            if ~isempty(cell2mat(strfind(dat.txtc(i,2),'BCB')))
                d(i)=1; % was 4; changed to 2 because dat.pos2 matrix was empty; seemed to fix it
            end
        end
        j=find(d==1);
        dat.std1i=j;
    end
    if strcmp(dat.std2,'LSVEC'),
        dat.std2c=dat.stddat_CO2(2,1);
        dat.std2o=dat.stddat_CO2(2,3);
        for i=1:size(dat.txtc,1)
            if ~isempty(cell2mat(strfind(dat.txtc(i,2),'LSVEC')))
                d(i)=2;
            end
        end
        j=find(d==2);
        dat.std2i=j;
    end
    if strcmp(dat.std2,'MCC'),
        dat.std2c=dat.stddat_CO2(4,1);
        dat.std2o=dat.stddat_CO2(4,3);
        for i=1:size(dat.txtc,1)
            if ~isempty(cell2mat(strfind(dat.txtc(i,2),'MCC')))
                d(i)=2; % was 4; changed to 2 because dat.pos2 matrix was empty; seemed to fix it
            end
        end
        j=find(d==2);
        dat.std2i=j;
    end
    if strcmp(dat.std2,'TJB'),
        dat.std2c=dat.stddat_CO2(8,1);
        dat.std2o=dat.stddat_CO2(8,3);
        for i=1:size(dat.txtc,1)
            if ~isempty(cell2mat(strfind(dat.txtc(i,2),'TJB')))
                d(i)=2; % was 4; changed to 2 because dat.pos2 matrix was empty; seemed to fix it
            end
        end
        j=find(d==2);
        dat.std2i=j;
    end
    dat.d=d;
    dat.pos1=find(dat.d==1);
    dat.pos2=find(dat.d==2);
    if isempty(dat.pos1) && isempty(dat.pos2),
        [dat]
        error('analyte CO2: no correcting standards found in sampleID list - check spelling?')
    end
end
% find the std positions: celluloses
if strcmp(dat.analyte,'CO'),
    % organic (cellulose) standards: C (1s) O (1s)
    dat.stddat_CO=[-25.3 0.19 31.0 0.24; % SAC
                -13.71 0.1 23.5 0.33; % AKC (PROVISIONAL 6/2014)
               -22.3 0.16 21.3 0.2; %AWS
               -12.0 0.3  31.85 0.14; % MASA
                -29.74 0.35 19.9 0.3;% H1
               -29.3 0.38 39.8 0.3;% L6
                -24.12 0.1 27.3 0.3;% Switsur
                -24.72 0.2 32.52 0.3; % IAEA-CH3 (Boettger)
                -27.42 0.07 13.26 0.22; % Lignin A (Hook)
                -20.99 0.11 11.96 0.26; % Lignin B (Hook)
                -21.10 0.03 12.73 0.33;% Lignin C (Hook)
                -29.97 0.14 5.71 0.38;]; % Lignin D (Hook)
                % 

    % check for CO : how can we write this to be totally general for any
    % two standards?
    % for now, it will be:
    % std1: SAC or HLB
    % std2: AKC or AWS or MASA or HLD
    % find the std positions 
    d=zeros(size(dat.txtc,1),1);
    if isempty(dat.std1) && isempty(dat.std2),
        error('analyte CO: no standards identified')
    end
    if strcmp(dat.std1,'SAC'),
        dat.std1c=dat.stddat_CO(1,1);
        dat.std1o=dat.stddat_CO(1,3);
        for i=1:size(dat.txtc,1)
            if ~isempty(cell2mat(strfind(dat.txtc(i,2),'SAC')))
                d(i)=1;
            end
        end
        j=find(d==1);
        dat.std1i=j;
    end
    if strcmp(dat.std1,'HLB'),
        dat.std1c=dat.stddat_CO(10,1);
        dat.std1o=dat.stddat_CO(10,3);
        for i=1:size(dat.txtc,1)
            if ~isempty(cell2mat(strfind(dat.txtc(i,2),'HLB')))
                d(i)=1;
            end
        end
        j=find(d==1);
        dat.std1i=j;
    end
    if strcmp(dat.std2,'AKC'),
        dat.std2c=dat.stddat_CO(2,1);
        dat.std2o=dat.stddat_CO(2,3);
        for i=1:size(dat.txtc,1)
            if ~isempty(cell2mat(strfind(dat.txtc(i,2),'AKC')))
                d(i)=2;
            end
        end
        j=find(d==2);
        dat.std2i=j;
    end
    if strcmp(dat.std2,'AWS'),
        dat.std2c=dat.stddat_CO(3,1);
        dat.std2o=dat.stddat_CO(3,3);
        for i=1:size(dat.txtc,1)
            if ~isempty(cell2mat(strfind(dat.txtc(i,2),'AWS')))
                d(i)=2;
            end
        end
        j=find(d==2);
        dat.std2i=j;
    end
    if strcmp(dat.std2,'MASA'),
        dat.std2c=dat.stddat_CO(4,1);
        dat.std2o=dat.stddat_CO(4,3);
        for i=1:size(dat.txtc,1)
            if ~isempty(cell2mat(strfind(dat.txtc(i,2),'MASA')))
                d(i)=2;
            end
        end
        j=find(d==2);
        dat.std2i=j;
    end
    if strcmp(dat.std2,'HLD'),
        dat.std2c=dat.stddat_CO(12,1);
        dat.std2o=dat.stddat_CO(12,3);
        for i=1:size(dat.txtc,1)
            if ~isempty(cell2mat(strfind(dat.txtc(i,2),'HLD')))
                d(i)=2;
            end
        end
        j=find(d==2);
        dat.std2i=j;
    end

    dat.d=d;
    dat.pos1=find(dat.d==1);
    dat.pos2=find(dat.d==2);
    if isempty(dat.pos1) && isempty(dat.pos2),
        [dat]
        error('analyte CO: no correcting standards found in sampleID list - check spelling?')
    end
end
return
