function [dat]=tpc2(dat,std1,std2)
% function[dat]=tpc1(dat,std1,std2)
% calculate the two point correction based on corrected and known values of
% the working standards
% v1 5/27/14 MNE

% 2pt correction as a function of position:
dat.tpc=nan(dat.nrc,4); % two 2pt corrections for each of two isotopes

% first, find out, what is the correction sequence:
% amplc --> splc, or splc ---> ampc?
% use clock to do this (see last lines of ampreg1.m and splreg1.m
% look for both minutes and seconds values
if dat.ampc_time(5)>=dat.splc_time(5) && dat.ampc_time(6)>dat.splc_time(6),
    disp('I think the spline correction was performed first')
    dat.cri=dat.ampc;
elseif dat.splc_time(5)>=dat.ampc_time(5) && dat.splc_time(6)>dat.ampc_time(6),
    disp('I think the amplitude correction was performed first')
    dat.cri=dat.splc;
end

for i=1:4 % for isotopes: C and O, for both std1 and std2 correction sets
    %d=nan(size(dat.cri(:,i)));
    if i==1, % carbon corrected using std1 or std2
        d=dat.cri(:,i)+dat.std1c; % case: c corrected with std1
        % slope calculation
        dat.slope_c(i)=(dat.std1c-dat.std2c)./(mean(d(dat.pos1))-mean(d(dat.pos2))); %known/measured
        dat.inter_c(i)=mean([dat.std1c dat.std2c])-dat.slope_c(i).*mean([mean(d(dat.pos1)) mean(d(dat.pos2))]);
        dat.tpc(:,i)=dat.inter_c(i)+dat.slope_c(i).*(dat.cri(:,i)+dat.std1c);
        disp(['2pt intercept, slope, carbon, ' dat.std1 ', is: ' num2str(dat.inter_c(i)) ' , ' num2str(dat.slope_c(i)) ]);
    elseif i==2,
        d=dat.cri(:,i)+dat.std1o; % case: o corrected with std1
        % slope calculation
        dat.slope_o(i)=(dat.std1o-dat.std2o)./(mean(d(dat.pos1))-mean(d(dat.pos2))); %known/measured
        dat.inter_o(i)=mean([dat.std1o dat.std2o])-dat.slope_o(i).*mean([mean(d(dat.pos1)) mean(d(dat.pos2))]);
        dat.tpc(:,i)=dat.inter_o(i)+dat.slope_o(i).*(dat.cri(:,i)+dat.std1o);
        disp(['2pt intercept, slope, oxygen, ' dat.std1 ', is: ' num2str(dat.inter_o(i)) ' , ' num2str(dat.slope_o(i)) ]);
    elseif i==3,
        d=dat.cri(:,i)+dat.std2c; % case: c corrected with std2
        % slope calculation
        dat.slope_c(i)=(dat.std1c-dat.std2c)./(mean(d(dat.pos1))-mean(d(dat.pos2))); %known/measured
        dat.inter_c(i)=mean([dat.std1c dat.std2c])-dat.slope_c(i).*mean([mean(d(dat.pos1)) mean(d(dat.pos2))]);
        dat.tpc(:,i)=dat.inter_c(i)+dat.slope_c(i).*(dat.cri(:,i)+dat.std2c);
        disp(['2pt intercept, slope, carbon, ' dat.std2 ', is: ' num2str(dat.inter_c(i)) ' , ' num2str(dat.slope_c(i)) ]);
    elseif i==4,
        d=dat.cri(:,i)+dat.std2o; % case: o corrected with std2
        % slope calculation
        dat.slope_o(i)=(dat.std1o-dat.std2o)./(mean(d(dat.pos1))-mean(d(dat.pos2))); %known/measured
        dat.inter_o(i)=mean([dat.std1o dat.std2o])-dat.slope_o(i).*mean([mean(d(dat.pos1)) mean(d(dat.pos2))]);
        dat.tpc(:,i)=dat.inter_o(i)+dat.slope_o(i).*(dat.cri(:,i)+dat.std2o);
        disp(['2pt intercept, slope, oxygen, ' dat.std2 ', is: ' num2str(dat.inter_o(i)) ' , ' num2str(dat.slope_o(i)) ]);
    end
end
% rewrite dat.slope and dat.inter to remove zeros from vectors
dat.slope_c=dat.slope_c([1 3]);dat.inter_c=dat.inter_c([1 3]);
dat.slope_o=dat.slope_o([2 4]);dat.inter_o=dat.inter_o([2 4]);

% check: by definition, these should be equal
disp(['2 point correction: known ' dat.std1 ', known ' dat.std2 ', 2pt-corr ' dat.std1 ', 2pt-corr ' dat.std2 ])
 [dat.std1c dat.std1o dat.std2c dat.std2o;
 mean(dat.tpc(dat.pos1,1)) mean(dat.tpc(dat.pos1,2)) mean(dat.tpc(dat.pos2,1)) mean(dat.tpc(dat.pos2,2));
 mean(dat.tpc(dat.pos1,3)) mean(dat.tpc(dat.pos1,4)) mean(dat.tpc(dat.pos2,3)) mean(dat.tpc(dat.pos2,4))]

disp(['calibration precisions on 2-pt corrected stds: C, O'])
['corr by ' dat.std1 ': ' num2str(std(dat.tpc(dat.pos1,1)),'%4.2f') ' , ' num2str(std(dat.tpc(dat.pos1,2)),'%4.2f')]
['corr by ' dat.std2 ': ' num2str(std(dat.tpc(dat.pos2,3)),'%4.2f') ' , ' num2str(std(dat.tpc(dat.pos2,4)),'%4.2f')]

% but the correction of std2 using std1 (or std1 using std2) as a correction basis needn't be so
% good, but should be close, if the corrections are valid:

disp(['validation precisions on 2-pt corrected stds: C, O'])
['corr by ' dat.std1 ': ' num2str(std(dat.tpc(dat.pos1,3)),'%4.2f') ' , ' num2str(std(dat.tpc(dat.pos1,4)),'%4.2f')]
['corr by ' dat.std2 ': ' num2str(std(dat.tpc(dat.pos2,1)),'%4.2f') ' , ' num2str(std(dat.tpc(dat.pos2,2)),'%4.2f')]

% report the average of the two two-point corrections
dat.crf=[nanmean(dat.tpc(:,[1 3]),2) nanmean(dat.tpc(:,[2 4]),2)];

disp([dat.std1 ': C, O precisions: ' dat.std1])
[nanmean(dat.crf(dat.pos1,1)) nanmean(dat.crf(dat.pos1,2));
    nanstd(dat.crf(dat.pos1,1)) nanstd(dat.crf(dat.pos1,2))]

disp([dat.std2 ': C, O precisions: ' dat.std2])
[nanmean(dat.crf(dat.pos2,1)) nanmean(dat.crf(dat.pos2,2));
    nanstd(dat.crf(dat.pos2,1)) nanstd(dat.crf(dat.pos2,2))]

return